summaryrefslogtreecommitdiffstats
path: root/kjsembed/bindings/painter_imp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/bindings/painter_imp.h')
-rw-r--r--kjsembed/bindings/painter_imp.h46
1 files changed, 23 insertions, 23 deletions
diff --git a/kjsembed/bindings/painter_imp.h b/kjsembed/bindings/painter_imp.h
index 0660a7ba..8b71a191 100644
--- a/kjsembed/bindings/painter_imp.h
+++ b/kjsembed/bindings/painter_imp.h
@@ -24,8 +24,8 @@
#include <kjsembed/jsbindingbase.h>
#include <kjsembed/jsproxy_imp.h>
-#include <qpen.h>
-#include <qpainter.h>
+#include <tqpen.h>
+#include <tqpainter.h>
class QPixmap;
@@ -46,22 +46,22 @@ class PainterRef
PainterRef();
~PainterRef();
- QPainter *painter();
+ TQPainter *painter();
- QPaintDevice *device();
- void setDevice(QPaintDevice *d);
+ TQPaintDevice *device();
+ void setDevice(TQPaintDevice *d);
void setCanDelete(bool can ) {m_canDelete = can;}
bool canDelete() const { return m_canDelete;}
private:
- QPainter *m_painter;
- QPaintDevice *m_device;
+ TQPainter *m_painter;
+ TQPaintDevice *m_device;
bool m_canDelete;
};
/**
* JSProxyImp binding for painting on a QPixmap.
*
* @author Richard Moore, rich@kde.org
*/
@@ -84,12 +84,12 @@ public:
private:
bool begin();
- bool begin(QPaintDevice *dev);
+ bool begin(TQPaintDevice *dev);
bool end();
- QPixmap pixmap() const;
- void setPen( const QPen& pn);
- QPen pen() const;
- QRect textBox(const QString &text);
+ TQPixmap pixmap() const;
+ void setPen( const TQPen& pn);
+ TQPen pen() const;
+ TQRect textBox(const TQString &text);
void moveTo( int x, int y );
void lineTo( int x, int y );
void drawPoint( int x, int y );
@@ -97,22 +97,22 @@ private:
void drawRect( int x, int y, int w, int h );
void drawRoundRect( int x, int y, int w, int h, int, int);
void drawEllipse( int x, int y, int w, int h );
- void drawText( int x, int y, const QString &txt );
+ void drawText( int x, int y, const TQString &txt );
void drawArc( int x, int y, int w, int h, int a, int alen );
void drawPie( int x, int y, int w, int h, int a, int alen );
- void drawPixmap ( int x, int y, const QPixmap &pixmap, int sx, int sy, int sw, int sh );
- void drawImage ( int x, int y, const QImage &image, int sx, int sy, int sw, int sh, int conversionFlags );
- void drawTiledPixmap ( int x, int y, int w, int h, const QPixmap &pixmap, int sx, int sy);
+ void drawPixmap ( int x, int y, const TQPixmap &pixmap, int sx, int sy, int sw, int sh );
+ void drawImage ( int x, int y, const TQImage &image, int sx, int sy, int sw, int sh, int conversionFlags );
+ void drawTiledPixmap ( int x, int y, int w, int h, const TQPixmap &pixmap, int sx, int sy);
void scale ( double sx, double sy );
void shear ( double sh, double sv );
void rotate ( double a );
void translate ( double dx, double dy );
- void setFont( const QFont &font);
- QFont font() const;
- void setBrush( const QColor &brush );
- QColor brush() const;
- QColor backgroundColor() const;
- void setBackgroundColor(const QColor &color);
+ void setFont( const TQFont &font);
+ TQFont font() const;
+ void setBrush( const TQColor &brush );
+ TQColor brush() const;
+ TQColor backgroundColor() const;
+ void setBackgroundColor(const TQColor &color);
private:
int mid;
@@ -46,22 +46,22 @@ class PainterRef
};
/**
- * JSProxyImp binding for painting on a QPixmap.
+ * JSProxyImp binding for painting on a TQPixmap.
*
* @author Richard Moore, rich@kde.org